@@ -1,8 +1,8 @@
 <?php
 /*
    Block Sender - A Plugin for SqurrelMail
-   Version: 1.0
-   Version Date: 14-Nov-2002
+   Version: 2.01
+   Version Date: 06-Jan-2003
    Author: Derek Battams <derek@battams.ca>
    Please see the README file for further information
 
@@ -10,10 +10,13 @@
 
 DATE          AUTHOR   CHANGE
 =============================================================================
+10-Oct-2002   F.Lewenda   Added i18n support
 21-Feb-2002   ddb      Completion of original version
 24-Feb-2002   ddb      Modified info passed to block_sender page from
                        block_sender_link()
 25-Jul-2002   ddb      Added wildcard domain blocking
+10-Oct-2002   fl       Added i18n support
+14-Nov-2002   ddb      Added support for SM >= 1.2.8
 
 Registers hooks for the plug; provides functions for these initial hooks.
 */
@@ -42,11 +45,17 @@ function block_sender_optionLink()
 // Create the link on the mail message page for blocking the current sender
 function block_sender_link()
 {
-   global $REQUEST_URI; // Message info contained in the URL
+   if(is_array($_SERVER))
+      $REQUEST_URI = $_SERVER["REQUEST_URI"]; // Message info contained in the URL
+   else
+   {
+      global $_SERVER;
+      $REQUEST_URI = $_SERVER["REQUEST_URI"];
+   }
   
    $msgInfo = substr($REQUEST_URI, strpos($REQUEST_URI, "?")+1);
-   echo "<br><a href=\"../plugins/block_sender/block_sender.php?$msgInfo\">Block Sender</a>";
-   echo "<br><a href=\"../plugins/block_sender/block_sender.php?$msgInfo&block_dom=1\">Block Sender's Domain</a>";
+   echo "<br><a href=\"../plugins/block_sender/block_sender.php?$msgInfo\">" . _("Block Sender") . "</a>";
+   echo "<br><a href=\"../plugins/block_sender/block_sender.php?$msgInfo&block_dom=1\">" . _("Block Sender's Domain") . "</a>";
 }
 
 ?>
